==> libbluray_0.5.0.orig.tar.bz2: libbluray-0.5.0/src/libbluray/bdj/java/org/havi/ui/HEmulatedGraphicsConfiguration.java <==
/*
 * This file is part of libbluray
 * Copyright (C) 2010  William Hahne
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 */

package org.havi.ui;

public class HEmulatedGraphicsConfiguration extends HGraphicsConfiguration {
    protected HEmulatedGraphicsConfiguration()
    {
        org.videolan.Logger.unimplemented(null, "HEmulatedGraphicsConfiguration");
    }

    public HGraphicsConfigTemplate getConfigTemplate()
    {
        org.videolan.Logger.unimplemented("HEmulatedGraphicsConfiguration", "getConfigTemplate");
        return null;
    }

    public HGraphicsConfigTemplate getEmulation()
    {
        org.videolan.Logger.unimplemented("HEmulatedGraphicsConfiguration", "getEmulation");
        return null;
    }

    public HGraphicsConfigTemplate getImplementation()
    {
        org.videolan.Logger.unimplemented("HEmulatedGraphicsConfiguration", "getImplementation");
        return null;
    }
}

==> libbluray-1.2.1.tar.bz2: libbluray-1.2.1/src/libbluray/bdj/java/org/havi/ui/HEmulatedGraphicsConfiguration.java <==
/*
 * This file is part of libbluray
 * Copyright (C) 2010  William Hahne
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 */

package org.havi.ui;

public class HEmulatedGraphicsConfiguration extends HGraphicsConfiguration {
    protected HEmulatedGraphicsConfiguration() {
        org.videolan.Logger.unimplemented(null, "HEmulatedGraphicsConfiguration");
    }

    public HGraphicsConfigTemplate getConfigTemplate() {
        org.videolan.Logger.unimplemented("HEmulatedGraphicsConfiguration", "getConfigTemplate");
        return null;
    }

    public HGraphicsConfigTemplate getEmulation() {
        org.videolan.Logger.unimplemented("HEmulatedGraphicsConfiguration", "getEmulation");
        return null;
    }

    public HGraphicsConfigTemplate getImplementation() {
        org.videolan.Logger.unimplemented("HEmulatedGraphicsConfiguration", "getImplementation");
        return null;
    }
}
